from fine_calculator.calculator import calculate_fine

# Test cases
test_cases = [10, 20, 30, 15.5, 25]

# Iterate over test cases
for days_overdue in test_cases:
    fine_amount = calculate_fine(days_overdue)
    print(f"For {days_overdue} days overdue, the fine amount is: ${fine_amount}")



from setuptools import setup, find_packages

setup(
    name='fine_calc',
    version='1.0.0',
    author='Chinmay Danwade',
    author_email='lawd7131@gmail.com',
    description='A Python library for calculating fines based on overdue days.',
    url='https://github.com/yourusername/chinmay-dhanawade',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)



# test_calculator.py

import unittest
from fine_calculator.calculator import calculate_fine

class TestFineCalculator(unittest.TestCase):

    def test_fine_calculation(self):
        # Test case for days overdue less than or equal to 15
        self.assertEqual(calculate_fine(10), 0)
        
        # Test case for days overdue greater than 15
        self.assertEqual(calculate_fine(20), 50)

if __name__ == '__main__':
    unittest.main()
